local LDB
local parent = CreateFrame('Frame')

 -- Get a reference to the lib
local LibQTip = LibStub('LibQTip-1.0')
local tooltip = nil
local tooltip2 = nil

local function UpdateDisplay()	
	if lastpetId ~= nil then
		LDB.text = lastpetText
		LDB.icon = lastpetIcon
	end
	
	local summonedPetID = C_PetJournal.GetSummonedPetGUID();
		
	if summonedPetID then
		local speciesID, customName, petlevel, xp, maxXp, displayID, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(summonedPetID)
		local creatureName = petName
			if customName then
				creatureName = customName
			end
			if creatureName then
			LDB.text = format("|cff00ff00%s|r", creatureName)
			LDB.icon = petIcon
			lastpetText = creatureName
			lastpetId = summonedPetID
			lastpetIcon = petIcon
			return
			end
	end
	
end

local function ModifiedClick(button, Id)
local speciesID, customName, petlevel, xp, maxXp, displayID, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(Id)
	local creatureName = petName
		if customName then
			creatureName = customName
		end
	
	if IsShiftKeyDown() then
		C_PetJournal.PickupPet(Id);
	elseif IsAltKeyDown() and not IsControlKeyDown() then
		fav1id = Id
		DEFAULT_CHAT_FRAME:AddMessage(string.format("|cffffff00BrokerPets:|r %s added as favorite 1.", creatureName))
	elseif IsControlKeyDown() and not IsAltKeyDown() then
		fav2id = Id
		DEFAULT_CHAT_FRAME:AddMessage(string.format("|cffffff00BrokerPets:|r %s added as favorite 2.", creatureName))
	elseif IsControlKeyDown() and IsAltKeyDown() then
		fav3id = Id
		DEFAULT_CHAT_FRAME:AddMessage(string.format("|cffffff00BrokerPets:|r %s added as favorite 3.", creatureName))
	else
		C_PetJournal.SummonPetByGUID(Id);
	end
	LibQTip:Release(tooltip)
	tooltip = nil
end

local function OnEnter(self)
tooltip2 = LibQTip:Acquire("BrokerPetsTooltip2", 1, "LEFT") 
self.tooltip2 = tooltip2
  
   -- Use smart anchoring code to anchor the tooltip to our frame
tooltip2:SmartAnchorTo(self)
tooltip2:Clear()
	local numPets, numOwned = C_PetJournal.GetNumPets(false);
	tooltip2:AddHeader('|cff00ffffBrokerPets|r')
	tooltip2:AddLine("<Right Click> to open pet list")
	tooltip2:AddLine("<Left Click> to summon/dismiss pet")
	tooltip2:AddLine("<Alt-Right Click> to summon a random pet")
	tooltip2:AddLine("<CTRL-Right Click> to summon a random favorite pet")
	tooltip2:AddLine("<Shift-Left Click> plugin to open pet journal")
	tooltip2:AddLine("<Shift-Right Click> plugin to open filter menu")
	tooltip2:AddLine("<Shift-Left Click> pet to pick it up")
	if fav1id then
	local speciesID, customName, petlevel, xp, maxXp, displayID, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(fav1id)
	local creatureName = petName
		if customName then
			creatureName = customName
		end	
		tooltip2:AddLine(format("<ALT-Click> |T%s:16|t%s", petIcon, creatureName))
	else
		tooltip2:AddLine("<ALT-Click> pet to set as favorite 1")
	end
	if fav2id then
	local speciesID, customName, petlevel, xp, maxXp, displayID, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(fav2id)
	local creatureName = petName
		if customName then
			creatureName = customName
		end	
		tooltip2:AddLine(format("<CTRL-Click> |T%s:16|t%s", petIcon, creatureName))
	else
		tooltip2:AddLine("<CTRL-Click> pet to set as favorite 2")
	end
	if fav3id then
	local speciesID, customName, petlevel, xp, maxXp, displayID, petName, petIcon, petType, creatureID = C_PetJournal.GetPetInfoByPetID(fav3id)
	local creatureName = petName
		if customName then
			creatureName = customName
		end	
		tooltip2:AddLine(format("<CTRL-ALT-Click> |T%s:16|t%s", petIcon, creatureName))
	else
		tooltip2:AddLine("<CTRL-ALT-Click> pet to set as favorite 3")
	end
	if numOwned == 0 then
		tooltip2:AddLine("|cffff0000You have no pets|r")
	else
		tooltip2:AddLine(string.format("|cff00ff00You have %s pets|r", numOwned))
	end
	 -- Show it
	if tooltip and tooltip:IsShown() then
		LibQTip:Release(self.tooltip2)
		self.tooltip2 = nil
	else
		tooltip2:Show()
	end
end

local function CreatePetTooltip(self)
   -- Acquire a tooltip with 1 columns, aligned to left
tooltip = LibQTip:Acquire("BrokerPetsTooltip", 1, "LEFT") 
self.tooltip = tooltip 
tooltip:EnableMouse(true)
tooltip:SetAutoHideDelay(1, self)
  
   -- Use smart anchoring code to anchor the tooltip to our frame
tooltip:SmartAnchorTo(self)
tooltip:Clear()
	local numPets, numOwned = C_PetJournal.GetNumPets(false)
	local summonedPetID = C_PetJournal.GetSummonedPetGUID();
	for i = 1, numPets do
		local petID, speciesID, isOwned, customName, petlevel, favorite, isRevoked, name, icon, petType, creatureID, sourceText, description, isWildPet = C_PetJournal.GetPetInfoByIndex(i)
			local creatureName = name
			if customName then
				creatureName = format("%s |cff00ffff(%s)|r", name, customName)
			end
		local isSummonable = C_PetJournal.PetIsSummonable(petID)
		if isOwned then
		 -- Add a new line, using all columns
			if isSummonable then
				if summonedPetID == petID then
					tooltip:AddLine(format("|T%s:16|t |cff00ff00%s|r", icon, creatureName))
					tooltip:SetCellScript(i, 1, "OnMouseUp", ModifiedClick, petID)
				else
					tooltip:AddLine(format("|T%s:16|t %s", icon, creatureName))
					tooltip:SetCellScript(i, 1, "OnMouseUp", ModifiedClick, petID)
				end
			else
				tooltip:AddLine(format("|T%s:16|t |cff848484%s|r", icon, creatureName))
				tooltip:SetCellScript(i, 1, "OnMouseUp", ModifiedClick, petID)
			end
		end				
	end
	tooltip:UpdateScrolling(500)
		-- Show it
	if tooltip:IsShown() then
		LibQTip:Release(self.tooltip)
		self.tooltip = nil	
	else
		tooltip:Show()
		LibQTip:Release(self.tooltip2)
		tooltip2 = nil
	end
end
 
local function OnLeave(self)   
   -- Release the tooltip
   LibQTip:Release(self.tooltip2)
   self.tooltip2 = nil  
end


local function OnClick(self, button)
	if (button == 'RightButton' and not IsShiftKeyDown() and not IsAltKeyDown() and not IsControlKeyDown()) then
		CreatePetTooltip(self)
	end
	if (IsShiftKeyDown() and button == 'LeftButton') then	
		TogglePetJournal(2)	
	end
	if (IsAltKeyDown() and not IsControlKeyDown() and button == 'RightButton') then
		C_PetJournal.SummonRandomPet(true)
	end
	if (IsControlKeyDown() and not IsAltKeyDown() and button == 'RightButton') then
		C_PetJournal.SummonRandomPet(false)
	end
	if (button == 'LeftButton' and not IsShiftKeyDown() and not IsAltKeyDown() and not IsControlKeyDown()) then	
		if lastpetId ~= nil then
			C_PetJournal.SummonPetByGUID(lastpetId);
		end
	end	
	if (IsShiftKeyDown() and button == 'RightButton') then
		if IsAddOnLoaded("Blizzard_PetJournal") then
			ToggleDropDownMenu(1, nil, PetJournalFilterDropDown, self, 0, 0)
		else
			local loaded, reason = LoadAddOn("Blizzard_PetJournal")
			ToggleDropDownMenu(1, nil, PetJournalFilterDropDown, self, 0, 0)
		end
	end
	if (button == 'LeftButton' and IsAltKeyDown() and not IsControlKeyDown()) then
		if fav1id ~= nil then
			C_PetJournal.SummonPetByGUID(fav1id)
		end
	end
	if (button == 'LeftButton' and IsControlKeyDown() and not IsAltKeyDown()) then
		if fav2id ~= nil then
			C_PetJournal.SummonPetByGUID(fav2id)
		end
	end
	if (button == 'LeftButton' and IsControlKeyDown() and IsAltKeyDown()) then
		if fav3id ~= nil then
			C_PetJournal.SummonPetByGUID(fav3id)
		end
	end
end

function parent:PLAYER_LOGIN()
	LDB = LibStub('LibDataBroker-1.1'):NewDataObject('BrokerPets', {
		icon = "Interface\\Icons\\INV_Misc_QuestionMark.blp",
		text = "BrokerPets",
		type = 'data source',
		--OnTooltipShow = OnTooltipShow,
		OnEnter = OnEnter,
		OnLeave = OnLeave,
		OnClick = OnClick,
	})

	self:RegisterEvent('COMPANION_UPDATE')
	self.COMPANION_UPDATE = UpdateDisplay
	
	self:RegisterEvent("PET_JOURNAL_LIST_UPDATE")
	self.PET_JOURNAL_LIST_UPDATE = UpdateDisplay

	UpdateDisplay()
end

 -- Somewhere in the anchor initialization
parent:SetScript('OnEnter', OnEnter)
parent:SetScript('OnLeave', OnLeave)
parent:SetScript('OnEvent', function(self, event, ...) self[event](self, ...) end)
parent:RegisterEvent('PLAYER_LOGIN')